@@ -115,15 +115,14 @@ void SAL_CALL Mapping_map_to_uno(
                 OUStringToOString(
                     OUSTR("[jni_uno bridge error] ") + err.m_message,
                     RTL_TEXTENCODING_ASCII_US ) );
-            OSL_ENSURE( 0, cstr_msg.getStr() );
+            OSL_FAIL( cstr_msg.getStr() );
 #else
             (void) err; // unused
 #endif
         }
         catch (::jvmaccess::VirtualMachine::AttachGuard::CreationException &)
         {
-            OSL_ENSURE(
-                0,
+            OSL_FAIL(
                 "[jni_uno bridge error] attaching current thread "
                 "to java failed!" );
         }
@@ -185,15 +184,14 @@ void SAL_CALL Mapping_map_to_java(
             OUStringToOString(
                 OUSTR("[jni_uno bridge error] ") + err.m_message,
                 RTL_TEXTENCODING_ASCII_US ) );
-        OSL_ENSURE( 0, cstr_msg.getStr() );
+        OSL_FAIL( cstr_msg.getStr() );
 #else
             (void) err; // unused
 #endif
     }
     catch (::jvmaccess::VirtualMachine::AttachGuard::CreationException &)
     {
-        OSL_ENSURE(
-            0,
+        OSL_FAIL(
             "[jni_uno bridge error] attaching current thread to java failed!" );
     }
 }
@@ -292,7 +290,7 @@ Bridge::~Bridge() SAL_THROW( () )
 
 
 //______________________________________________________________________________
-void JNI_context::java_exc_occured() const
+void JNI_context::java_exc_occurred() const
 {
     // !don't rely on JNI_info!
 
@@ -302,7 +300,7 @@ void JNI_context::java_exc_occured() const
     if (! jo_exc.is())
     {
         throw BridgeRuntimeError(
-            OUSTR("java exception occured, but not available!?") +
+            OUSTR("java exception occurred, but not available!?") +
             get_stack_trace() );
     }
 
@@ -544,15 +542,14 @@ void SAL_CALL uno_ext_getMapping(
                 OUStringToOString(
                     OUSTR("[jni_uno bridge error] ") + err.m_message,
                     RTL_TEXTENCODING_ASCII_US ) );
-            OSL_ENSURE( 0, cstr_msg.getStr() );
+            OSL_FAIL( cstr_msg.getStr() );
 #else
             (void) err; // unused
 #endif
         }
         catch (::jvmaccess::VirtualMachine::AttachGuard::CreationException &)
         {
-            OSL_ENSURE(
-                0,
+            OSL_FAIL(
                 "[jni_uno bridge error] attaching current thread "
                 "to java failed!" );
         }
