@@ -45,7 +45,6 @@
 #include <com/sun/star/bridge/XUnoUrlResolver.hpp>
 
 using namespace cppu;
-using namespace rtl;
 using namespace osl;
 using namespace com::sun::star::uno;
 using namespace com::sun::star::lang;
@@ -53,6 +52,8 @@ using namespace com::sun::star::connection;
 using namespace com::sun::star::bridge;
 using namespace com::sun::star::registry;
 
+using ::rtl::OUString;
+
 #define SERVICENAME		"com.sun.star.bridge.UnoUrlResolver"
 #define IMPLNAME		"com.sun.star.comp.bridge.UnoUrlResolver"
 
@@ -240,12 +241,6 @@ void SAL_CALL component_getImplementationEnvironment(
     *ppEnvTypeName = CPPU_CURRENT_LANGUAGE_BINDING_NAME;
 }
 //==================================================================================================
-sal_Bool SAL_CALL component_writeInfo(
-    void * pServiceManager, void * pRegistryKey )
-{
-    return component_writeInfoHelper( pServiceManager, pRegistryKey, g_entries );
-}
-//==================================================================================================
 void * SAL_CALL component_getFactory(
     const sal_Char * pImplName, void * pServiceManager, void * pRegistryKey )
 {
